"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var viewer_component_1 = require("../viewer.component");
var universal_pdf_plugin_1 = require("./universal-pdf.plugin");
var util_1 = require("../../../util");
var PdfViewer = /** @class */ (function (_super) {
    __extends(PdfViewer, _super);
    /**
     * @stable [16.03.2020]
     * @param {IPdfViewerProps} props
     */
    function PdfViewer(props) {
        var _this = _super.call(this, props) || this;
        _this.canvasRef = React.createRef();
        _this.pdfRendererPlugin = new universal_pdf_plugin_1.UniversalPdfPlugin(_this.settings.urls.pdfWorker + "?_dc=" + _this.environment.appVersion, function () { return _this.canvasRef.current; }, _this.onLoadSucceed.bind(_this), _this.onLoadError.bind(_this));
        return _this;
    }
    /**
     * @stable [16.03.2020]
     */
    PdfViewer.prototype.componentWillUnmount = function () {
        this.pdfRendererPlugin.cancel();
        this.pdfRendererPlugin = null;
        _super.prototype.componentWillUnmount.call(this);
    };
    /**
     * @stable [16.03.2020]
     */
    PdfViewer.prototype.refreshOnSrcChanges = function () {
        var _this = this;
        util_1.ifNotNilThanValue(this.props.src, function (src) {
            // This plugin can't process the null value
            _this.pdfRendererPlugin
                .setSrc(src)
                .setPage(_this.actualOrDefaultPage)
                .setScale(_this.actualScale)
                .loadDocument();
        });
    };
    /**
     * @stable [16.03.2020]
     */
    PdfViewer.prototype.refreshOnInternalChanges = function () {
        this.pdfRendererPlugin
            .setPage(this.actualOrDefaultPage)
            .setScale(this.actualScale)
            .refreshPage();
    };
    /**
     * @stable [16.03.2020]
     * @returns {JSX.Element}
     */
    PdfViewer.prototype.getContentElement = function () {
        return React.createElement("canvas", { ref: this.canvasRef });
    };
    /**
     * @stable [16.03.2020]
     * @returns {JSX.Element}
     */
    PdfViewer.prototype.gePreviewElement = function () {
        return (React.createElement(PdfViewer, { usePreview: false, src: this.props.src, page: this.actualOrDefaultPreviewPage, scale: this.actualPreviewScale }));
    };
    /**
     * @stable [16.03.2020]
     * @returns {boolean}
     */
    PdfViewer.prototype.isPreviewForwardActionDisabled = function () {
        return this.actualOrDefaultPreviewPage === this.pdfRendererPlugin.numPages;
    };
    Object.defineProperty(PdfViewer.prototype, "isProgressMessageRendered", {
        /**
         * @stable [16.03.2020]
         * @returns {boolean}
         */
        get: function () {
            return !this.pdfRendererPlugin.hasLoadedDocument;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @stable [16.03.2020]
     * @param {AnyT} error
     */
    PdfViewer.prototype.onLoadError = function (error) {
        this.setState({ error: error });
    };
    /**
     * @stable [16.03.2020]
     */
    PdfViewer.prototype.onLoadSucceed = function () {
        this.setState({ error: null });
    };
    return PdfViewer;
}(viewer_component_1.Viewer));
exports.PdfViewer = PdfViewer;
//# sourceMappingURL=pdf-viewer.component.js.map